from numerous_image_tools.image_test.environment import read_set_numerous_environment
read_set_numerous_environment('..')
from numerous_image_tools.basic_job.runner import run

def test_run_job_local():

    exit_ = run('numerous_job_package.job_module.entrypoint')
    assert exit_ == "", "The job exited with non empty traceback: "+str(exit_)

def test_run_job_local_with_error():

    exit_ = run('numerous_job_package.job_module.entrypoint_with_error')
    assert exit_ == "", "The job exited with non empty traceback: "+str(exit_)